@@ -37,19 +37,6 @@ typedef struct _GMimeFilterYenc GMimeFilterYenc;
 typedef struct _GMimeFilterYencClass GMimeFilterYencClass;
 
 
-/**
- * GMimeFilterYencDirection:
- * @GMIME_FILTER_YENC_DIRECTION_ENCODE: yEncode.
- * @GMIME_FILTER_YENC_DIRECTION_DECODE: yDecode.
- *
- * The direction the #GMimeFilterYenc should convert.
- **/
-typedef enum {
-	GMIME_FILTER_YENC_DIRECTION_ENCODE,
-	GMIME_FILTER_YENC_DIRECTION_DECODE
-} GMimeFilterYencDirection;
-
-
 /**
  * GMIME_YDECODE_STATE_INIT:
  *
@@ -134,10 +121,21 @@ typedef enum {
  **/
 #define GMIME_YENCODE_CRC_FINAL(crc) (~crc)
 
+/**
+ * GMimeFilterYenc:
+ * @parent_object: parent #GMimeFilter
+ * @encode: encode vs decode
+ * @part: part id
+ * @state: encode/decode state
+ * @pcrc: part crc
+ * @crc: full crc
+ *
+ * A filter for yEncoding or yDecoding a stream.
+ **/
 struct _GMimeFilterYenc {
 	GMimeFilter parent_object;
 	
-	GMimeFilterYencDirection direction;
+	gboolean encode;
 	
 	int part;
 	
@@ -154,7 +152,7 @@ struct _GMimeFilterYencClass {
 
 GType g_mime_filter_yenc_get_type (void);
 
-GMimeFilter *g_mime_filter_yenc_new (GMimeFilterYencDirection direction);
+GMimeFilter *g_mime_filter_yenc_new (gboolean encode);
 
 void g_mime_filter_yenc_set_state (GMimeFilterYenc *yenc, int state);
 void g_mime_filter_yenc_set_crc (GMimeFilterYenc *yenc, guint32 crc);
@@ -164,11 +162,11 @@ guint32 g_mime_filter_yenc_get_pcrc (GMimeFilterYenc *yenc);
 guint32 g_mime_filter_yenc_get_crc (GMimeFilterYenc *yenc);
 
 
-size_t g_mime_ydecode_step  (const unsigned char *in, size_t inlen, unsigned char *out,
+size_t g_mime_ydecode_step  (const unsigned char *inbuf, size_t inlen, unsigned char *outbuf,
 			     int *state, guint32 *pcrc, guint32 *crc);
-size_t g_mime_yencode_step  (const unsigned char *in, size_t inlen, unsigned char *out,
+size_t g_mime_yencode_step  (const unsigned char *inbuf, size_t inlen, unsigned char *outbuf,
 			     int *state, guint32 *pcrc, guint32 *crc);
-size_t g_mime_yencode_close (const unsigned char *in, size_t inlen, unsigned char *out,
+size_t g_mime_yencode_close (const unsigned char *inbuf, size_t inlen, unsigned char *outbuf,
 			     int *state, guint32 *pcrc, guint32 *crc);
 
 G_END_DECLS
