@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
+/*  GMime
  *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
@@ -24,14 +24,16 @@
 
 G_BEGIN_DECLS
 
+gboolean g_mime_parse_content_type (const char **in, char **type, char **subtype);
+
 void g_mime_decode_lwsp (const char **in);
 #define decode_lwsp(in) g_mime_decode_lwsp (in)
 
-char *g_mime_decode_word (const char **in);
+const char *g_mime_decode_word (const char **in);
 #define decode_word(in) g_mime_decode_word (in)
 
-char *g_mime_decode_domain (const char **in);
-#define decode_domain(in) g_mime_decode_domain (in)
+gboolean g_mime_decode_domain (const char **in, GString *domain);
+#define decode_domain(in, domain) g_mime_decode_domain (in, domain)
 
 G_END_DECLS
 
